@@ -2777,6 +2777,11 @@ impl_refresh (GbfProject *_project,
 		g_signal_emit_by_name (G_OBJECT (project), "project-updated");
 }
 
+static GbfProjectCapabilities
+impl_get_capabilities (GbfProject *_project, GError    **error)
+{
+	return GBF_PROJECT_CAN_ADD_NONE;
+}
 
 static void
 foreach_build_target (gpointer key, gpointer value, gpointer data)
@@ -3644,6 +3649,7 @@ gbf_mkfile_project_class_init (GbfMkfileProjectClass *klass)
 	project_class->clean = impl_clean;
 	project_class->probe = impl_probe;
 	project_class->refresh = impl_refresh;
+	project_class->get_capabilities = impl_get_capabilities;
 
 	project_class->get_build_targets = impl_get_build_targets;
 	project_class->add_build_callback = impl_add_build_callback;
